@@ -2,7 +2,8 @@
  * This file is part of nzbget. See <https://nzbget.com>.
  *
  * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
- *
+ * Copyright (C) 2024 Denis <denis@nzbget.com>
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -57,6 +58,7 @@ var Status = (new function($)
 	var playInitialized = false;
 	var modalShown = false;
 	var titleGen = [];
+	var subscribers = [];
 
 	var validTimePatterns = [
 		/^=\d{1,2}(:[0-5][0-9])?$/, // 24h exact
@@ -65,6 +67,11 @@ var Status = (new function($)
 		/^\d+(h|m)?$/i, // relative minutes or hours
 	];
 
+	this.getStatus = function()
+	{
+		return status;
+	}
+
 	this.init = function()
 	{
 		$CHPauseDownload = $('#CHPauseDownload');
@@ -114,7 +121,10 @@ var Status = (new function($)
 			function(curStatus)
 			{
 				status = curStatus;
+				status.DownloadRate = Util.joinInt64(status.DownloadRateHi, status.DownloadRateLo);
+				status.AverageDownloadRate = Util.joinInt64(status.AverageDownloadRateHi, status.AverageDownloadRateLo);
 				_this.status = status;
+				notifyStatusSubs(status);
 				StatDialog.update();
 			});
 	}
@@ -125,6 +135,16 @@ var Status = (new function($)
 		StatDialog.redraw();
 	}
 
+	this.subscribe = function(sub)
+	{
+		subscribers.push(sub);
+	}
+
+	function notifyStatusSubs(status)
+	{
+		subscribers.forEach(function(sub) { sub.update(status); });
+	}
+
 	function redrawInfo()
 	{
 		Util.show($CHPauseDownload, status.DownloadPaused);
@@ -740,7 +760,7 @@ var StatDialog = (new function($)
 
 		if (status.ResumeTime > 0)
 		{
-			content += '<tr><td>Autoresume</td><td class="text-right">' + Util.formatTimeHMS(status.ResumeTime - status.ServerTime) + '<i class="icon-empty"/></td></tr>';
+			content += '<tr><td>Autoresume</td><td class="text-right">' + Util.formatTimeHMS(status.ResumeTime - status.ServerTime) + '<i class="material-icon"/></td></tr>';
 		}
 
 		$('#StatusTable tbody').html(content);
@@ -1058,14 +1078,15 @@ var StatDialog = (new function($)
 			defaultAxis: {
 				labels: true,
 				labelsProps: {
-					'font-size': 13
+					'font-size': 13,
+					'fill': '#3a87ad'
 				},
 				labelsDistance: 12
 			},
 			axis: {
 				l: {
 					labels: true,
-					suffix: units
+					suffix: units,
 				}
 			},
 			features: {
@@ -1144,8 +1165,8 @@ var StatDialog = (new function($)
 
 	function updateRangeButtons()
 	{
-		$('#StatDialog_Toolbar .volume-range').removeClass('btn-inverse');
-		$('#StatDialog_Volume_' + curRange + ',#StatDialog_Volume_' + curRange + '2,#StatDialog_Volume_' + curRange + '3').addClass('btn-inverse');
+		$('#StatDialog_Toolbar .volume-range').removeClass('btn-active');
+		$('#StatDialog_Volume_' + curRange + ',#StatDialog_Volume_' + curRange + '2,#StatDialog_Volume_' + curRange + '3').addClass('btn-active');
 	}
 
 	function updateServerList()
@@ -1161,14 +1182,32 @@ var StatDialog = (new function($)
 			var name = server.ID + '. ' + Status.serverName(server);
 			var item = menuItemTemplate.clone().removeClass('volume-server-template hide').addClass('volume-server');
 			var a = $('a', item);
-			a.html('<i class="' + (i === curServer-1 ? 'icon-ok' : 'icon-empty') + '"></i>' + Util.textToHtml(name));
+
+			if (i === curServer-1)
+			{
+				a.html('<i class="material-icon">done</i>' + Util.textToHtml(name));
+			}
+			else
+			{
+				a.html('<i class="material-icon"></i>' + Util.textToHtml(name));
+			}
+
 			a.attr('data-id', server.ID);
 			a.click(chooseServer);
 			insertPos.before(item);
 		}
 
 		$('#StatDialog_ServerCap').text(curServer > 0 ? Status.serverName(Status.status.NewsServers[curServer-1]) : 'All news servers');
-		$('#StatDialog_ServerMenuAll i').toggleClass('icon-ok', curServer === 0).toggleClass('icon-empty', curServer !== 0);
+
+		var serverMenuAllBtn = $('#StatDialog_ServerMenuAll i');
+		if (curServer === 0)
+		{
+			serverMenuAllBtn.text('done');
+		}
+		else
+		{
+			serverMenuAllBtn.text('');
+		}
 	}
 
 	function chooseServer(server)
@@ -1236,7 +1275,16 @@ var StatDialog = (new function($)
 
 			var item = menuItemTemplate.clone().removeClass('volume-month-template hide').addClass('volume-month');
 			var a = $('a', item);
-			a.html('<i class="' + (monId === curMonth ? 'icon-ok' : 'icon-empty') + '"></i>' + name);
+
+			if (monId === curMonth)
+			{
+				a.html('<i class="material-icon">done</i>' + name);
+			}
+			else
+			{
+				a.html('<i class="material-icon"></i>' + name);
+			}
+
 			a.attr('data-id', monId);
 			a.click(chooseMonth);
 			insertPos.before(item);
@@ -1262,7 +1310,16 @@ var StatDialog = (new function($)
 
 			var item = menuItemTemplate.clone().removeClass('volume-month-template hide').addClass('volume-month');
 			var a = $('a', item);
-			a.html('<i class="' + (monId === curMonth  ? 'icon-ok' : 'icon-empty') + '"></i>' + name);
+
+			if (monId === curMonth)
+			{
+				a.html('<i class="material-icon">done</i>' + name);
+			}
+			else
+			{
+				a.html('<i class="material-icon"></i>' + name);
+			}
+
 			a.attr('data-id', monId);
 			a.click(chooseMonth);
 			insertPos.before(item);
