@@ -2,7 +2,8 @@
  * This file is part of nzbget. See <https://nzbget.com>.
  *
  * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
- *
+ * Copyright (C) 2024 Denis <denis@nzbget.com>
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -30,6 +31,27 @@ var Util = (new function($)
 {
 	'use strict';
 
+	this.saveToLocalStorage = function(key, val)
+	{
+		try 
+		{
+			localStorage.setItem(key, val);
+		} catch (error) 
+		{
+			console.error(error);
+		}
+	}
+
+	this.getFromLocalStorage = function(key)
+	{
+		return localStorage.getItem(key);
+	}
+
+	this.removeFromLocalStorage = function(key)
+	{
+		return localStorage.removeItem(key);
+	}
+
 	this.formatTimeHMS = function(sec)
 	{
 		var hms = '';
@@ -82,8 +104,18 @@ var Util = (new function($)
 		return seconds + 's';
 	}
 
+	this.isNumber = function(value)
+	{
+		return typeof value === 'number';
+	}
+
 	this.formatDateTime = function(unixTime)
 	{
+		if (!Util.isNumber(unixTime) || unixTime < 0)
+		{
+			return '';
+		}
+
 		var dt = new Date(unixTime * 1000);
 		var h = dt.getHours();
 		var m = dt.getMinutes();
@@ -100,60 +132,117 @@ var Util = (new function($)
 
 		if (sizeMB >= 1024 * 1024 * 100)
 		{
-			return this.round0(sizeMB / 1024.0 / 1024.0) + '&nbsp;TB';
+			return Math.floor(sizeMB / 1024.0 / 1024.0) + ' TB';
 		}
 		else if (sizeMB >= 1024 * 1024 * 10)
 		{
-			return this.round1(sizeMB / 1024.0 / 1024.0) + '&nbsp;TB';
+			return this.round1(sizeMB / 1024.0 / 1024.0) + ' TB';
 		}
 		else if (sizeMB >= 1024 * 1000)
 		{
-			return this.round2(sizeMB / 1024.0 / 1024.0) + '&nbsp;TB';
+			return this.round2(sizeMB / 1024.0 / 1024.0) + ' TB';
 		}
 		else if (sizeMB >= 1024 * 100)
 		{
-			return this.round0(sizeMB / 1024.0) + '&nbsp;GB';
+			return Math.floor(sizeMB / 1024.0) + ' GB';
 		}
 		else if (sizeMB >= 1024 * 10)
 		{
-			return this.round1(sizeMB / 1024.0) + '&nbsp;GB';
+			return this.round1(sizeMB / 1024.0) + ' GB';
 		}
 		else if (sizeMB >= 1000)
 		{
-			return this.round2(sizeMB / 1024.0) + '&nbsp;GB';
+			return this.round2(sizeMB / 1024.0) + ' GB';
 		}
 		else if (sizeMB >= 100)
 		{
-			return this.round0(sizeMB) + '&nbsp;MB';
+			return Math.floor(sizeMB) + ' MB';
 		}
 		else if (sizeMB >= 10)
 		{
-			return this.round1(sizeMB) + '&nbsp;MB';
+			return this.round1(sizeMB) + ' MB';
 		}
 		else
 		{
-			return this.round2(sizeMB) + '&nbsp;MB';
+			return this.round2(sizeMB) + ' MB';
 		}
 	}
 
-	this.formatSpeed = function(bytesPerSec)
+	this.formatSpeed = function (bytesPerSec) 
 	{
-		if (bytesPerSec >= 100 * 1024 * 1024)
+		if (!Util.isNumber(bytesPerSec) || bytesPerSec <= 0) 
 		{
-			return Util.round0(bytesPerSec / 1024.0 / 1024.0) + '&nbsp;MB/s';
+			return '';
 		}
-		else if (bytesPerSec >= 10 * 1024 * 1024)
+
+		if (bytesPerSec >= 100 * 1024 * 1024 * 1024) 
 		{
-			return Util.round1(bytesPerSec / 1024.0 / 1024.0) + '&nbsp;MB/s';
+			return Util.round0(bytesPerSec / 1024 / 1024 / 1024) + ' GB/s';
 		}
-		else if (bytesPerSec >= 1024 * 1000)
+		else if (bytesPerSec >= 10 * 1024 * 1024 * 1024) 
 		{
-			return Util.round2(bytesPerSec / 1024.0 / 1024.0) + '&nbsp;MB/s';
+			return Util.round1(bytesPerSec / 1024 / 1024 / 1024) + ' GB/s';
 		}
-		else
+		else if (bytesPerSec >= 1024 * 1024 * 1024) 
 		{
-			return Util.round0(bytesPerSec / 1024.0) + '&nbsp;KB/s';
+			return Util.round2(bytesPerSec / 1024 / 1024 / 1024) + ' GB/s';
 		}
+		if (bytesPerSec >= 100 * 1024 * 1024) 
+		{
+			return Util.round0(bytesPerSec / 1024.0 / 1024.0) + ' MB/s';
+		}
+		else if (bytesPerSec >= 10 * 1024 * 1024) 
+		{
+			return Util.round1(bytesPerSec / 1024.0 / 1024.0) + ' MB/s';
+		}
+		else if (bytesPerSec >= 1024 * 1000) 
+		{
+			return Util.round2(bytesPerSec / 1024.0 / 1024.0) + ' MB/s';
+		}
+
+		return Util.round0(bytesPerSec / 1024.0) + ' KB/s';
+	}
+
+	this.formatNetworkSpeed = function(speedMbps) 
+	{
+		if (!Util.isNumber(speedMbps))
+		{
+			return '';
+		}
+
+		if (!speedMbps || speedMbps < 0)
+		{
+			return '';
+		}
+
+		if (speedMbps >= 10000) 
+		{
+			return Util.round1(speedMbps / 10000) + ' Gbps';
+		}
+		if (speedMbps >= 1000) 
+		{
+			return Util.round1(speedMbps / 1000) + ' Gbps';
+		} 
+		else if (speedMbps >= 100) 
+		{
+			return Util.round0(speedMbps) + ' Mbps';
+		} 
+		else if (speedMbps >= 10) 
+		{
+			return Util.round1(speedMbps) + ' Mbps';
+		} 
+		else if (speedMbps >= 1) 
+		{
+			return Util.round2(speedMbps) + ' Mbps';
+		}
+
+		return Util.round0(speedMbps * 1000) + ' Kbps';
+	}
+
+	this.formatSpeedWithCustomUnit = function (bytesPerSec, unit) 
+	{
+		var res = this.formatSpeed(bytesPerSec);
+		return res.replace('B', unit);
 	}
 
 	this.formatAge = function(time)
@@ -346,6 +435,11 @@ var Util = (new function($)
 		return text.replace(/ |\/|\\|\.|\$|\:|\*/g, '_');
 	}
 
+	this.joinInt64 = function(hi, lo)
+	{
+		return (hi << 32) + lo;
+	}
+
 }(jQuery));
 
 
